Evohome Client - Version 1
==========================

Instantiating the client
------------------------

.. code-block:: python

    from evohomeclient import EvohomeClient

    client = EvohomeClient('username', 'password')

Contents:

.. toctree::
   :maxdepth: 2

   temperature
   hotwater
   modes
